/*
 * jWindowPager v1.0.0
 *
 * Copyright (c) 2012 Tyler Brown
 * Licensed under the MIT license.
 *
 */

(function($){

	$.jWindowPager = function(contentElement, options){
		var base = this;
		base.$elContent = $(contentElement); // content element, jquery ref
		base.elContent = contentElement; // content element, dom ref
		base.$elContent.data("jWindowPager", base);
		
		base.init = function(){
			base.options = $.extend({},$.jWindowPager.defaultOptions, options);

			// initial vars
			base.contentWidth = base.$elContent.width();
			base.currentPage = 1;
			base.totalPages = Math.ceil(base.contentWidth / base.options.windowWidth);

			// create containing, window, paging, & control elements
			base.$elContent.addClass('jwp_content').wrap('<div class="jwp_window" />'); // wrap content in window
			base.$elWindow = base.$elContent.parent();
			base.$elWindow.wrap('<div class="jwp_container" />'); // wrap window in container
			base.$elContainer = base.$elWindow.parent();
			base.$elContainer.append('<div class="jwp_prev"></div>');
			base.$elContainer.append('<div class="jwp_selectors_con"><ul class="jwp_selectors"></ul></div>');
			base.$elContainer.append('<div class="jwp_next"></div>');
			base.$elPrevButton = base.$elContainer.find('.jwp_prev');
			base.$elNextButton = base.$elContainer.find('.jwp_next');
			base.$elSelectors = base.$elContainer.find('.jwp_selectors');

			// modify those elements and bind events
			base.$elContainer.attr({'data-total-pages': base.totalPages})
			base.$elWindow.width(base.options.windowWidth).css({overflow: 'hidden'});
			base.$elPrevButton.html(base.options.prevHTML).on('click', base.prevPage);
			base.$elNextButton.html(base.options.nextHTML).on('click', base.nextPage);;
			for(var i = 1; i <= base.totalPages; i++) {
				base.$elSelectors.append('<li class="jwp_selector" data-page="'+i+'">'+i+'</li>');
			}
			base.$elSelectors.on('click', '.jwp_selector', function() {
				var page = $(this).data('page');
				base.goToPage(page);
			});

			// go
			base.goToPage(1);
		};

		base.goToPage = function(pageNum) {
			if(pageNum < 1) pageNum = 1;
			if(pageNum > base.totalPages) pageNum = base.totalPages;
			var offset = (pageNum-1) * base.options.windowWidth * -1;
			base.$elContent.animate({marginLeft: offset.toString()+'px'}, base.options.animationSpeed);
			base.$elSelectors.find('.jwp_selector.selected').removeClass('selected');
			base.$elSelectors.find('.jwp_selector[data-page="'+pageNum+'"]').addClass('selected');
		};
		base.nextPage = function() {
			base.currentPage++;
			if(base.currentPage > base.totalPages) base.currentPage = 1;
			base.goToPage(base.currentPage);
		};
		base.prevPage = function() {
			base.currentPage--;
			if(base.currentPage < 1) base.currentPage = base.totalPages;
			base.goToPage(base.currentPage);
		};
		
		base.init();
	};
	
	$.jWindowPager.defaultOptions = {
		windowWidth: 600,
		animationSpeed: 300,
		nextHTML: 'next',
		prevHTML: 'prev',
		onChange: function() {}
	};
	
	$.fn.jWindowPager = function(options){
		return this.each(function(){
			(new $.jWindowPager(this, options));
		});
	};

	$.fn.getjWindowPager = function(){
		return this.data("jWindowPager");
	};

})(jQuery);
